@@ -1,12 +1,10 @@
-// @ts-check
-
 export class ArrayBase extends Array {
   constructor({ source, tokens }) {
     super();
     Object.defineProperties(this, {
       source: { value: source },
       tokens: { value: tokens },
-      parent: { value: null, writable: true }
+      parent: { value: null, writable: true },
     });
   }
 }
