@@ -1,11 +1,9 @@
-// @ts-check
-
 import { Container } from "./container.js";
 import { Field } from "./field.js";
 
 export class Dictionary extends Container {
   /**
-   * @param {import("../tokeniser").Tokeniser} tokeniser
+   * @param {import("../tokeniser.js").Tokeniser} tokeniser
    * @param {object} [options]
    * @param {import("../tokeniser.js").Token} [options.partial]
    */
@@ -15,13 +13,14 @@ export class Dictionary extends Container {
     if (!tokens.base) {
       return;
     }
-    return Container.parse(tokeniser, new Dictionary({ source: tokeniser.source, tokens }), {
-      type: "dictionary",
-      inheritable: !partial,
-      allowedMembers: [
-        [Field.parse],
-      ]
-    });
+    return Container.parse(
+      tokeniser,
+      new Dictionary({ source: tokeniser.source, tokens }),
+      {
+        inheritable: !partial,
+        allowedMembers: [[Field.parse]],
+      }
+    );
   }
 
   get type() {
