@@ -19,15 +19,18 @@ export class Mixin extends Container {
     if (!tokens.mixin) {
       return;
     }
-    return Container.parse(tokeniser, new Mixin({ source: tokeniser.source, tokens }), {
-      type: "interface mixin",
-      allowedMembers: [
-        [Constant.parse],
-        [stringifier],
-        [Attribute.parse, { noInherit: true }],
-        [Operation.parse, { regular: true }]
-      ]
-    });
+    return Container.parse(
+      tokeniser,
+      new Mixin({ source: tokeniser.source, tokens }),
+      {
+        allowedMembers: [
+          [Constant.parse],
+          [stringifier],
+          [Attribute.parse, { noInherit: true }],
+          [Operation.parse, { regular: true }],
+        ],
+      }
+    );
   }
 
   get type() {
