@@ -1,5 +1,6 @@
 "use strict";
 
+/* eslint-disable array-element-newline */
 module.exports = new Set([
   "break", "case", "class", "catch", "const", "continue", "debugger", "default", "delete",
   "do", "else", "export", "extends", "finally", "for", "function", "if", "import", "in", "instanceof",
@@ -9,4 +10,5 @@ module.exports = new Set([
 
   "package", "protected", "static", "interface", "private", "public",
 
-  "null", "true", "false"]);
+  "null", "true", "false"
+]);
